@@ -36,6 +36,13 @@
 #undef STRICT
 #endif
 
+#ifdef G_OS_WIN32
+/* No hardcoded paths in the binary, thanks */
+#undef PKGLIBDIR
+/* It's OK to leak this, as PKGLIBDIR is invoked only once */
+#define PKG_CONFIG_PATH g_strconcat (g_win32_get_package_installation_directory (PACKAGE, NULL), "\\lib\\pkgconfig", NULL)
+#endif
+
 static int want_debug_spew = 0;
 static int want_verbose_errors = 0;
 static int want_stdout_errors = 0;
@@ -72,7 +79,8 @@ verbose_error (const char *format, ...)
 {
   va_list args;
   gchar *str;
-
+  FILE* stream;
+  
   g_return_if_fail (format != NULL);
 
   if (!want_verbose_errors)
@@ -82,8 +90,13 @@ verbose_error (const char *format, ...)
   str = g_strdup_vprintf (format, args);
   va_end (args);
 
-  fputs (str, stderr);
-  fflush (stdout);
+  if (want_stdout_errors)
+    stream = stdout;
+  else
+    stream = stderr;
+  
+  fputs (str, stream);
+  fflush (stream);
 
   g_free (str);
 }
@@ -159,29 +172,33 @@ pkg_uninstalled (Package *pkg)
 int
 main (int argc, char **argv)
 {
-  static int want_my_version = 0;
-  static int want_version = 0;
-  static int want_libs = 0;
-  static int want_cflags = 0;
-  static int want_l_libs = 0;
-  static int want_L_libs = 0;
-  static int want_other_libs = 0;
-  static int want_I_cflags = 0;
-  static int want_other_cflags = 0;
-  static int want_list = 0;
-  static int result;
-  static int want_uninstalled = 0;
-  static char *variable_name = NULL;
-  static int want_exists = 0;
-  static char *required_atleast_version = NULL;
-  static char *required_exact_version = NULL;
-  static char *required_max_version = NULL;
-  static char *required_pkgconfig_version = NULL;
-  static int want_silence_errors = 0;
+  int want_my_version = 0;
+  int want_version = 0;
+  int want_libs = 0;
+  int want_cflags = 0;
+  int want_l_libs = 0;
+  int want_L_libs = 0;
+  int want_other_libs = 0;
+  int want_I_cflags = 0;
+  int want_other_cflags = 0;
+  int want_list = 0;
+  int want_static_lib_list = ENABLE_INDIRECT_DEPS;
+  int result;
+  int want_uninstalled = 0;
+  char *variable_name = NULL;
+  int want_exists = 0;
+  char *required_atleast_version = NULL;
+  char *required_exact_version = NULL;
+  char *required_max_version = NULL;
+  char *required_pkgconfig_version = NULL;
+  int want_silence_errors = 0;
   GString *str;
   GSList *packages = NULL;
   char *search_path;
   char *pcbuilddir;
+  const char *pkglibdir;
+  char **search_dirs;
+  char **iter;
   gboolean need_newline;
 
   const char *pkgname;
@@ -199,6 +216,8 @@ main (int argc, char **argv)
       "require given version of pkg-config", "VERSION" },
     { "libs", 0, POPT_ARG_NONE, &want_libs, 0,
       "output all linker flags" },
+    { "static", 0, POPT_ARG_NONE, &want_static_lib_list, 0,
+      "output linker flags for static linking" },
     { "libs-only-l", 0, POPT_ARG_NONE, &want_l_libs, 0,
       "output -l flags" },
     { "libs-only-other", 0, POPT_ARG_NONE, &want_other_libs, 0,
@@ -260,26 +279,13 @@ main (int argc, char **argv)
     }
 
   search_path = getenv ("PKG_CONFIG_PATH");
-  if (search_path)
+  if (search_path) 
     {
-      char **search_dirs;
-      char **iter;
-
-      search_dirs = g_strsplit (search_path, G_SEARCHPATH_SEPARATOR_S, -1);
-
-      iter = search_dirs;
-      while (*iter)
-        {
-          debug_spew ("Adding directory '%s' from PKG_CONFIG_PATH\n",
-                      *iter);
-          add_search_dir (*iter);
-
-          ++iter;
-        }
-
-      g_strfreev (search_dirs);
+      add_search_dirs(search_path, G_SEARCHPATH_SEPARATOR_S);
     }
 
+  add_search_dirs(PKG_CONFIG_PC_PATH, G_SEARCHPATH_SEPARATOR_S);
+
 #ifdef G_OS_WIN32
   {
     /* Add search directories from the Registry */
@@ -466,6 +472,10 @@ main (int argc, char **argv)
                            req->name,
                            req->version);
 
+	    if (req->url)
+	      verbose_error ("You may find new versions of %s at %s\n",
+			     req->name, req->url);
+
             return 1;
           }
 
@@ -584,14 +594,14 @@ main (int argc, char **argv)
 
   if (want_l_libs)
     {
-      char *str = packages_get_l_libs (packages);
+      char *str = packages_get_l_libs (packages, want_static_lib_list);
       printf ("%s ", str);
       g_free (str);
       need_newline = TRUE;
     }
   else if (want_L_libs)
     {
-      char *str = packages_get_L_libs (packages);
+      char *str = packages_get_L_libs (packages, want_static_lib_list);
       printf ("%s ", str);
       g_free (str);
       need_newline = TRUE;
@@ -605,7 +615,7 @@ main (int argc, char **argv)
     }
   else if (want_libs)
     {
-      char *str = packages_get_all_libs (packages);
+      char *str = packages_get_all_libs (packages, want_static_lib_list);
       printf ("%s ", str);
       g_free (str);
       need_newline = TRUE;
